"use client";

import React, { useState } from 'react';
import EpisodesTab from '@/app/components/EpisodesTabs'; // Ensure the correct import path
import RelatedTVShows from '@/app/components/RelatedTvShows'; // Ensure the correct import path
import { motion, AnimatePresence } from 'framer-motion';

interface TVWatchTabsProps {
  tvShowId: number;
  seasons: Array<{ season_number: number }>;  // Ensure that each season has a season_number
}

export default function TVWatchTabs({ tvShowId, seasons }: TVWatchTabsProps) {
  const [activeTab, setActiveTab] = useState<'episodes' | 'related'>('episodes');

  // Extract the season numbers from the seasons array
  const seasonNumbers = seasons.map(season => season.season_number);

  return (
    <div className="my-8">
      <div className="flex justify-center space-x-4 mb-6">
        <button
          className={`text-lg font-bold transition-colors duration-300 ${
            activeTab === 'episodes' ? 'text-white border-b-2 border-red-600' : 'text-gray-500 hover:text-gray-300'
          }`}
          onClick={() => setActiveTab('episodes')}
        >
          Episodes
        </button>
        <button
          className={`text-lg font-bold transition-colors duration-300 ${
            activeTab === 'related' ? 'text-white border-b-2 border-red-600' : 'text-gray-500 hover:text-gray-300'
          }`}
          onClick={() => setActiveTab('related')}
        >
          Related TV Shows
        </button>
      </div>

      <AnimatePresence mode="wait">
        {activeTab === 'episodes' && (
          <motion.div
            key="episodes"
            initial={{ opacity: 0, x: -50 }}
            animate={{ opacity: 1, x: 0 }}
            exit={{ opacity: 0, x: 50 }}
            transition={{ duration: 0.5 }}
          >
            <EpisodesTab tvShowId={tvShowId} seasons={seasonNumbers} />
          </motion.div>
        )}
        {activeTab === 'related' && (
          <motion.div
            key="related"
            initial={{ opacity: 0, x: -50 }}
            animate={{ opacity: 1, x: 0 }}
            exit={{ opacity: 0, x: 50 }}
            transition={{ duration: 0.5 }}
          >
            <RelatedTVShows tvShowId={tvShowId} />
          </motion.div>
        )}
      </AnimatePresence>
    </div>
  );
}
